require 'spec_helper'

describe Quby::Compiler::Entities::LookupTables do
  let(:lookup_tables) { described_class.new(File.join(__dir__, "..", "..", "..", "fixtures", "lookup_tables")) }
  let(:csv_key) { 'test' }
  let(:tree) { lookup_tables.fetch(csv_key) }

  it 'finds the levels correctly' do
    expect(tree[:levels]).to eq(["scale", "gender", "age", "raw", "norm"])
  end

  it 'builds the tree' do
    expect(tree[:tree]).to eq(
      "Inhibitie" => {
        "male" => {
          (10.0...11.0) => {
            (-Float::INFINITY...10.0) => 39.0,
            (10.0...20.0) => 42.0,
            (20.0...30.0) => 71.0,
            (30.0...Float::INFINITY) => 75.0
          }
        }
      }
    )
  end

  describe 'definition containing float values' do
    let(:csv_key) { "test2" }

    it 'finds the levels correctly' do
      expect(tree[:levels]).to eq(["scale", "raw", "norm"])
    end

    it 'builds the tree' do
      expect(tree[:tree]).to eq("Inhibitie" => {15.0=>39.0, 16.0=>42.0, 17.0=>71.0, 18.0=>75.0})
    end
  end

  describe 'definition containing range with float values' do
    let(:csv_key) { 'float_test' }

    it 'finds the levels correctly' do
      expect(tree[:levels]).to eq(["scale", "gender", "age", "raw", "norm"])
    end

    it 'builds the tree' do
      expect(tree[:tree]).to eq(
        "Inhibitie" => {
          "male" => {
            (10.0...11.0) => {
              (-Float::INFINITY...10.5) => 39.0,
              (10.5...20.1) => 42.0,
              (20.1...30.7) => 71.0,
              (30.7...Float::INFINITY) => 75.0
            }
          }
        }
      )
    end
  end

  context 'invalid csv data' do
    let(:csv_key) { 'bad_range' }
    it 'fails when csv data contains a range between two equal values' do
      expect { tree }.to raise_error(RuntimeError, 'Cannot create range between two equal values')
    end
  end
end
