require 'spec_helper'

describe Quby::Compiler::Outputs::RoquaSerializer do
  it 'generates outcome schemas' do
    questionnaire = dsl("test") do
      title "Test Quest"

      score_schema :score0, 'Score 0' do
        # By default, scores end up in the :main table
        subscore :something, 'Nog iets', export_key: :score0 do
          'Iets'
        end
      end

      score_schema :score1, 'Score 1' do
        subscore :value, 'Waarde', export_key: :score1, outcome_table: :values do
          1
        end
        subscore :int, 'Interpretatie', export_key: :score1_i, outcome_table: :values do
          'Wah'
        end
      end

      score_schema :score2, 'Score 2' do
        subscore :value, 'Waarde', export_key: :score2, outcome_table: :values do
          2
        end
      end

      score_schema :score3, 'Score 3' do
        subscore :mean, 'Gemiddelde', export_key: :score3, outcome_table: :means do
          1
        end
      end
    end
    serializer = described_class.new(questionnaire)
    expect(serializer.as_json).to \
      include({
                outcome_tables_schema: {
                  headers: {int: "Interpretatie", mean: "Gemiddelde", something: "Nog iets", value: "Waarde"},
                  tables: {
                    main: {:score_keys => [:score0], :subscore_keys => [:something]},
                    values: {:score_keys => [:score1, :score2], :subscore_keys => [:value, :int]},
                    means: {:score_keys => [:score3], :subscore_keys => [:mean]}
                  }
                }
              })
  end

  def dsl(key, &block)
    Quby::Compiler::DSL.build(key, nil, &block)
  end
end